@@ -1397,7 +1397,7 @@ _&&_(_==_(list~type(list(dyn))^list,
 	{
 		in: `[].map(x, [].map(y, x in y && y in x))`,
 		err: `
-		ERROR: <input>:1:33: found no matching overload for '@in' applied to '(type_param:"_var2" , type_param:"_var0" )'
+		ERROR: <input>:1:33: found no matching overload for '@in' applied to '(_var2, _var0)'
 		| [].map(x, [].map(y, x in y && y in x))
 		| ................................^`,
 	},
@@ -1908,6 +1908,134 @@ _&&_(_==_(list~type(list(dyn))^list,
 			__result__~list(list(list(int)))^__result__)~list(list(list(int)))
 		  `,
 	},
+	{
+		in:      `values.filter(i, i.content != "").map(i, i.content)`,
+		outType: decls.NewListType(decls.String),
+		env: testEnv{
+			idents: []*exprpb.Decl{
+				decls.NewVar("values", decls.NewListType(decls.NewMapType(decls.String, decls.String))),
+			},
+		},
+		out: `__comprehension__(
+			// Variable
+			i,
+			// Target
+			__comprehension__(
+			  // Variable
+			  i,
+			  // Target
+			  values~list(map(string, string))^values,
+			  // Accumulator
+			  __result__,
+			  // Init
+			  []~list(map(string, string)),
+			  // LoopCondition
+			  true~bool,
+			  // LoopStep
+			  _?_:_(
+				_!=_(
+				  i~map(string, string)^i.content~string,
+				  ""~string
+				)~bool^not_equals,
+				_+_(
+				  __result__~list(map(string, string))^__result__,
+				  [
+					i~map(string, string)^i
+				  ]~list(map(string, string))
+				)~list(map(string, string))^add_list,
+				__result__~list(map(string, string))^__result__
+			  )~list(map(string, string))^conditional,
+			  // Result
+			  __result__~list(map(string, string))^__result__)~list(map(string, string)),
+			// Accumulator
+			__result__,
+			// Init
+			[]~list(string),
+			// LoopCondition
+			true~bool,
+			// LoopStep
+			_+_(
+			  __result__~list(string)^__result__,
+			  [
+				i~map(string, string)^i.content~string
+			  ]~list(string)
+			)~list(string)^add_list,
+			// Result
+			__result__~list(string)^__result__)~list(string)`,
+	},
+	{
+		in:      `[{}.map(c,c,c)]+[{}.map(c,c,c)]`,
+		outType: decls.NewListType(decls.NewListType(decls.Bool)),
+		out: `_+_(
+			[
+			  __comprehension__(
+				// Variable
+				c,
+				// Target
+				{}~map(bool, dyn),
+				// Accumulator
+				__result__,
+				// Init
+				[]~list(bool),
+				// LoopCondition
+				true~bool,
+				// LoopStep
+				_?_:_(
+				  c~bool^c,
+				  _+_(
+					__result__~list(bool)^__result__,
+					[
+					  c~bool^c
+					]~list(bool)
+				  )~list(bool)^add_list,
+				  __result__~list(bool)^__result__
+				)~list(bool)^conditional,
+				// Result
+				__result__~list(bool)^__result__)~list(bool)
+			]~list(list(bool)),
+			[
+			  __comprehension__(
+				// Variable
+				c,
+				// Target
+				{}~map(bool, dyn),
+				// Accumulator
+				__result__,
+				// Init
+				[]~list(bool),
+				// LoopCondition
+				true~bool,
+				// LoopStep
+				_?_:_(
+				  c~bool^c,
+				  _+_(
+					__result__~list(bool)^__result__,
+					[
+					  c~bool^c
+					]~list(bool)
+				  )~list(bool)^add_list,
+				  __result__~list(bool)^__result__
+				)~list(bool)^conditional,
+				// Result
+				__result__~list(bool)^__result__)~list(bool)
+			]~list(list(bool))
+		  )~list(list(bool))^add_list`,
+	},
+	{
+		in: "type(testAllTypes.nestedgroup.nested_id) == int",
+		env: testEnv{
+			idents: []*exprpb.Decl{
+				decls.NewVar("testAllTypes", decls.NewObjectType("google.expr.proto2.test.TestAllTypes")),
+			},
+		},
+		outType: decls.Bool,
+		out: `_==_(
+			type(
+			  testAllTypes~google.expr.proto2.test.TestAllTypes^testAllTypes.nestedgroup~google.expr.proto2.test.TestAllTypes.NestedGroup.nested_id~int
+			)~type(int)^type,
+			int~type(int)^int
+		  )~bool^equals`,
+	},
 }
 
 var testEnvs = map[string]testEnv{
